# Copyright 2017 6WIND S.A.

import charms.reactive as reactive
import charmhelpers.core.host as host
import charmhelpers.core.hookenv as hookenv
import charmhelpers.contrib.openstack.utils as ch_utils

import charms_openstack.charm as charm
import charm.openstack.virtual_accelerator as va

# import 6WIND layer
import charm.openstack.utils as va_utils

NOVA_DEFAULT_CONFS = {
    'liberty': [
        ('monkey_patch', 'true'),
        ('monkey_patch_modules', 'nova.virt.libvirt.vif:openstack_6wind_extensions.liberty.nova.virt.libvirt.vif.decorator'),
    ],
    'mitaka': [
        ('monkey_patch', 'true'),
        ('monkey_patch_modules', 'nova.virt.libvirt.vif:openstack_6wind_extensions.mitaka.nova.virt.libvirt.vif.decorator'),
    ],
    'newton': [
        ('monkey_patch', 'true'),
        ('monkey_patch_modules', 'nova.virt.libvirt.vif:openstack_6wind_extensions.newton.nova.virt.libvirt.vif.decorator'),
    ],
    'ocata': [
        ('monkey_patch', 'true'),
        ('monkey_patch_modules', 'nova.virt.libvirt.vif:openstack_6wind_extensions.ocata.nova.virt.libvirt.vif.decorator'),
    ],
    'pike': [
        ('monkey_patch', 'true'),
        ('monkey_patch_modules', 'nova.virt.libvirt.vif:openstack_6wind_extensions.pike.nova.virt.libvirt.vif.decorator'),
    ],
    'queens':[
        ('monkey_patch', 'true'),
        ('monkey_patch_modules', 'nova.virt.libvirt.vif:openstack_6wind_extensions.queens.nova.virt.libvirt.vif.decorator'),
    ]
}

va_common = va_utils.VirtualAcceleratorCharmTools()

@reactive.when_not('charm.installed')
def install_packages():
    with charm.provide_charm_instance() as va_charm:
        va_charm.install_prerequisites()
        va_charm.delete_default_libvirt_net()
        va_common.install_credentials()
        va_common.install_va()
        va_common.install_license()
        va_charm.install_os_extensions()
        va_charm.start()
        hookenv.status_set('active', 'Unit is ready')
    reactive.set_state('charm.installed')

@reactive.when('config.changed', 'charm.installed')
def config_changed():
    with charm.provide_charm_instance() as va_charm:
        va_charm.render_config()
        va_charm.restart()
        hookenv.status_set('active', 'Unit is ready')

@reactive.when('neutron-plugin.connected', 'charm.installed')
def configure_neutron_plugin(neutron_plugin):
    release = ch_utils.os_release('nova-common')
    neutron_plugin.configure_plugin(
        plugin='ovs',
        config={
            "nova-compute": {
                "/etc/nova/nova.conf": {
                    "sections": {
                        'DEFAULT': NOVA_DEFAULT_CONFS[release],
                    }
                }
            }
        }
    )
    # Assess status, to update Workload and Agent states in `juju status`
    with charm.provide_charm_instance() as va_charm:
        va_charm.assess_status()

@reactive.when('neutron-plugin.connected')
def set_conn_state(neutron_plugin):
    reactive.set_state('plugin-connected-once')

@reactive.when('plugin-connected-once')
@reactive.when_not('neutron-plugin.connected')
@reactive.when_not('departed')
def departing():
    with charm.provide_charm_instance() as va_charm:
        va_charm.stop()
        va_charm.uninstall_os_extensions()
        va_common.uninstall_license()
        va_common.uninstall_va()
        # uninstall only once
        reactive.set_state('departed')
